@@ -234,6 +234,14 @@ void helperReportMem(uint64_t &currRPos, uint64_t &currQPos, uint64_t totalRBits
                 rQue-=2;
                 break;
             }
+            /* if current rRef/rQue plus matchSize smaller than minMEMLength, then simply return.
+             * Note that one less character is compared due to a mismatch 
+             */
+            if (rRef+matchSize-lRef < static_cast<uint64_t>(commonData::minMemLen))
+            {
+                return;
+            }
+
             mismatch=1;
             matchSize/=2;
             if (matchSize%2)
@@ -488,7 +496,7 @@ void checkCommandLineOptions(uint32_t &options)
 void print_help_msg()
 {
     cout <<  endl;
-    cout << "E-MEM Version 1.0.0, Sep. 25, 2014" << endl;
+    cout << "E-MEM Version 1.0.1, Dec. 12, 2017" << endl;
     cout << "© 2014 Nilesh Khiste, Lucian Ilie" << endl;
     cout <<  endl;
     cout << "E-MEM finds and outputs the position and length of all maximal" << endl;
@@ -739,6 +747,7 @@ int main (int argc, char *argv[])
     QueryFile.closeFile();
 
     arrayTmpFile.removeDuplicates(refSeqInfo, querySeqInfo, revComplement);
+    fflush(0);
     return 0;
 }
 
